#include <Arduino.h>
#include <Wire.h>
#include "RTCLib.h"   // RTCLib by Neiro (JeeLabs), but modified by me

// Manual for library: http://lygte-info.dk/project/
// This is version 1.00 from 2019-10-1
// By HKJ from lygte-info.dk

// Select one RTC chip 
//DS1302 rtc(A3,A5,A4);  // Note pin assigment: A3:CE/RST, A5:CLK, A4:DAT

// A4:SDA, A5:SCL on UNO and Nano
//DS1307 rtc;  
DS3231 rtc;   
//PCF8563 rtc;
//PCF8583 rtc;



DateTime dt(SECONDS_FROM_1970_TO_2000);   // Zero the time

void setup() {
  Serial.begin(9600);
  if (rtc.useWire()) {
    Wire.begin();
  }
  Serial.println("Test precision time on RTC clock");

  rtc.begin(); 
  // Initialize clock to a low day number, code cannot handle a month change
  rtc.adjust(dt);
}

// Read the time from the RTC, I want seconds since I started the test
unsigned long getRTCTime() {
  DateTime dt=rtc.now();    
  return dt.second()+dt.minute()*60+dt.hour()*3600+(dt.day()-1)*3600L*24;
}

// This routine will return current time in seconds
void startCalibration() {
  Serial.println("StartCalibration");
  delay(100);
  Serial.begin(76800);  // This has very low error making it a reliable baudrate
  delay(500);
  Serial.println("StartCalibration fast");
  boolean done = false;
  TIMSK0 &= ~(1 << TOIE0); // Disable millis interrupt
  while (!done) {
    if (Serial.available() > 0) {
      switch (Serial.read()) {
        case '?' : {
            unsigned long v = getRTCTime();
            while (v == getRTCTime());
            Serial.println(v);
          }
          break;
        case 'f' : Serial.println("X0"); break; // This program do not use the library and do not have access to the value
        case 'q' : done = true; break;
      }
    }
  }
  TIMSK0 |= (1 << TOIE0); // Enable millis interrupt
  Serial.begin(9600);
}


// Wait for the calibration commands, while waiting list seconds.
void loop() {
  if (Serial.available() > 0) {
    switch (Serial.read()) {
      case '#': startCalibration(); break;
    }
  }
  Serial.print("Seconds: ");
  Serial.println(getRTCTime());
  
  delay(1000);
}
